@@ -9,7 +9,7 @@ use JSON::PP qw( encode_json );
 use Encode qw( encode_utf8 );
 
 # ABSTRACT: Dist::Zilla initialization tasks for Plicease
-our $VERSION = '1.88'; # VERSION
+our $VERSION = '1.89'; # VERSION
 
 
 with 'Dist::Zilla::Role::AfterMint';
@@ -202,7 +202,7 @@ sub gather_files_tests
   $name =~ s{-}{::}g;
 
   my $use_t_file = Dist::Zilla::File::InMemory->new({
-    name => 't/use.t',
+    name => 't/01_use.t',
     content => join("\n", q{use strict;},
                           q{use warnings;},
                           q{use Test::More tests => 1;},
@@ -328,7 +328,7 @@ Dist::Zilla::Plugin::Author::Plicease::Init2 - Dist::Zilla initialization tasks
 
 =head1 VERSION
 
-version 1.88
+version 1.89
 
 =head1 DESCRIPTION
 
